0.9.9 API documentation: intersect.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

intersect.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include <cfloat>
18 #include <limits>
19 #include "../glm.hpp"
20 #include "../geometric.hpp"
21 #include "../gtx/closest_point.hpp"
22 #include "../gtx/vector_query.hpp"
23
24 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
25 # ifndef GLM_ENABLE_EXPERIMENTAL
26 # pragma message("GLM: GLM_GTX_closest_point is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
27 # else
28 # pragma message("GLM: GLM_GTX_closest_point extension included")
29 # endif
30 #endif
31
32 namespace glm
33 {
36
40 template<typename genType>
41 GLM_FUNC_DECL bool intersectRayPlane(
42 genType const& orig, genType const& dir,
43 genType const& planeOrig, genType const& planeNormal,
44 typename genType::value_type & intersectionDistance);
45
49 template<typename T, qualifier Q>
50 GLM_FUNC_DECL bool intersectRayTriangle(
51 vec<3, T, Q> const& orig, vec<3, T, Q> const& dir,
52 vec<3, T, Q> const& v0, vec<3, T, Q> const& v1, vec<3, T, Q> const& v2,
53 vec<2, T, Q>& baryPosition, T& distance);
54
57 template<typename genType>
58 GLM_FUNC_DECL bool intersectLineTriangle(
59 genType const& orig, genType const& dir,
60 genType const& vert0, genType const& vert1, genType const& vert2,
61 genType & position);
62
66 template<typename genType>
67 GLM_FUNC_DECL bool intersectRaySphere(
68 genType const& rayStarting, genType const& rayNormalizedDirection,
69 genType const& sphereCenter, typename genType::value_type const sphereRadiusSquared,
70 typename genType::value_type & intersectionDistance);
71
74 template<typename genType>
75 GLM_FUNC_DECL bool intersectRaySphere(
76 genType const& rayStarting, genType const& rayNormalizedDirection,
77 genType const& sphereCenter, const typename genType::value_type sphereRadius,
78 genType & intersectionPosition, genType & intersectionNormal);
79
82 template<typename genType>
83 GLM_FUNC_DECL bool intersectLineSphere(
84 genType const& point0, genType const& point1,
85 genType const& sphereCenter, typename genType::value_type sphereRadius,
86 genType & intersectionPosition1, genType & intersectionNormal1,
87 genType & intersectionPosition2 = genType(), genType & intersectionNormal2 = genType());
88
90 }//namespace glm
91
92 #include "intersect.inl"
glm::intersectRayTriangle
GLM_FUNC_DECL bool intersectRayTriangle(vec< 3, T, Q > const &orig, vec< 3, T, Q > const &dir, vec< 3, T, Q > const &v0, vec< 3, T, Q > const &v1, vec< 3, T, Q > const &v2, vec< 2, T, Q > &baryPosition, T &distance)
Compute the intersection of a ray and a triangle.
glm::intersectRaySphere
GLM_FUNC_DECL bool intersectRaySphere(genType const &rayStarting, genType const &rayNormalizedDirection, genType const &sphereCenter, const typename genType::value_type sphereRadius, genType &intersectionPosition, genType &intersectionNormal)
Compute the intersection of a ray and a sphere.
glm::intersectRayPlane
GLM_FUNC_DECL bool intersectRayPlane(genType const &orig, genType const &dir, genType const &planeOrig, genType const &planeNormal, typename genType::value_type &intersectionDistance)
Compute the intersection of a ray and a plane.
glm::intersectLineTriangle
GLM_FUNC_DECL bool intersectLineTriangle(genType const &orig, genType const &dir, genType const &vert0, genType const &vert1, genType const &vert2, genType &position)
Compute the intersection of a line and a triangle.
glm::intersectLineSphere
GLM_FUNC_DECL bool intersectLineSphere(genType const &point0, genType const &point1, genType const &sphereCenter, typename genType::value_type sphereRadius, genType &intersectionPosition1, genType &intersectionNormal1, genType &intersectionPosition2=genType(), genType &intersectionNormal2=genType())
Compute the intersection of a line and a sphere.
glm::distance
GLM_FUNC_DECL T distance(vec< L, T, Q > const &p0, vec< L, T, Q > const &p1)
Returns the distance betwwen p0 and p1, i.e., length(p0 - p1).
glm
Definition: common.hpp:20